/////////////////////////////////////////////////////////////////////////////
///
/// @file indknown.h
///
/// Known Conley indices for a dynamical system.
/// Prepare a customized version of this file every time
/// a different system is considered if the Conley indices
/// which cannot be computed are actually known apriori
/// (e.g., for the origin if it is not isolated).
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started on April 5, 2008. Last revision: April 5, 2008.


#ifndef _CMGRAPHS_INDKNOWN_H_
#define _CMGRAPHS_INDKNOWN_H_

// include selected header files from the CHomP library
#include "chomp/system/textfile.h"
#include "chomp/homology/chains.h"
#include "chomp/struct/integer.h"

// include local header files
#include "config.h"
#include "typedefs.h"
#include "conindex.h"
#include "morsedec.h"
#include "typedyns.h"


namespace custom {

/// Dummy version of a function for the computation of Conley indices
/// of Morse sets which fail the isolation condition.
namespace noKnownIndices {


// --------------------------------------------------
// ---------------- set Conley index ----------------
// --------------------------------------------------

/// Assigns a prescribed Conley index to the given Morse set
/// whose index could not be computed because of the lack of isolation.
/// This procedure assigns the known index of the origin
/// for the Leslie population model which comes from the linearization,
/// based on its eigenvalues computed by hand for the 2-dimensional model:
/// lambda_1 = theta_1 and lambda_2 = -p theta_2 / theta_1.
/// Returns "true" if the index was set, "false" otherwise.
inline bool setConleyIndex (theMorseDecompositionType &morseDec, int n,
	int subdivDepth, const double *leftMapParam,
	const double *rightMapParam, int paramCount)
{
	return false;
} /* setConleyIndex */


} // namespace noKnownIndices
} // namespace custom


#endif // _CMGRAPHS_INDKNOWN_H_

