/////////////////////////////////////////////////////////////////////////////
///
/// @file m_inf.h
///
/// The time-t map for an infectious disease model.
/// This map defines a sample time-t map for an ODE.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started on March 13, 2013. Last revision: March 13, 2013.


#ifndef _CMGRAPHS_INF_H_
#define _CMGRAPHS_INF_H_


// include local header files
#include "maptype.h"
#include "odetimet.h"


// --------------------------------------------------
// ----------------- the time-t map -----------------
// --------------------------------------------------

/// This class defines the time-t map for the equations.
class MapInf: public MapOdeTimeT
{
public:
	/// The constructor of a map object.
	MapInf ();

}; /* class MapInf */

// --------------------------------------------------

// Following (7) from the notes from Oct 13, 2013.
inline MapInf::MapInf ():
	MapOdeTimeT (
#ifdef _CAPD29_
	"var:i1,v1,i2,v2,"
	"pa,pb,pc,pd,pe,pf,pg,ph,pi,pj,pk,pl,pm,pn,po,pp;fun:"
#else
	"par:pa,pb,pc,pd,pe,pf,pg,ph,pi,pj,pk,pl,pm,pn,po,pp;"
	"var:i1,v1,i2,v2;fun:"
#endif
//	"((pe*((pa-i1)-((1-pm)*v1))*i1)-((pg+pi+pc)*i1))+(pd*i2),"
//	"(((po*(pa-i1))-(pm*pe*v1*i1))-((pg+pk+po+pc)*v1))+(pd*v2),"
//	"((pf*((pb-i2)-((1-pn)*v2))*i2)-((ph+pj+pd)*i2))+(pc*i1),"
//	"(((pp*(pb-i2))-(pn*pf*v2*i2))-((ph+pl+pp+pd)*v2))+(pc*v1);",
	"((pe*((pa-i1)-((1-pm)*v1))*i1)-((pg+pi+pc)*i1))+("
#ifdef ALPHA1_EQ_ALPHA2
	"pc"
#else
	"pd"
#endif
	"*i2),"
	"(((po*(pa-i1))-(pm*pe*v1*i1))-((pg+pk+po+pc)*v1))+("
#ifdef ALPHA1_EQ_ALPHA2
	"pc"
#else
	"pd"
#endif
	"*v2),"
	"(("
#ifdef BETA1_EQ_BETA2
	"pe"
#else
	"pf"
#endif
	"*((pb-i2)-((1-pn)*v2))*i2)-((ph+pj+"
#ifdef ALPHA1_EQ_ALPHA2
	"pc"
#else
	"pd"
#endif
	")*i2))+(pc*i1),"
	"(((pp*(pb-i2))-(pn*"
#ifdef BETA1_EQ_BETA2
	"pe"
#else
	"pf"
#endif
	"*v2*i2))-((ph+pl+pp+"
#ifdef ALPHA1_EQ_ALPHA2
	"pc"
#else
	"pd"
#endif
	")*v2))+(pc*v1);",
	3, 1.0/128, 10)
{
	return;
} /* MapInf::MapInf */


#endif // _CMGRAPHS_INF_H_

