/////////////////////////////////////////////////////////////////////////////
///
/// @file typedyns.h
///
/// Data types for the dynamical systems data structures.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2014 by Pawel Pilarczyk.
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started on October 3, 2008. Last revision: July 12, 2012.


#ifndef _CMGRAPHS_TYPEDYNS_H_
#define _CMGRAPHS_TYPEDYNS_H_


// include local header files
#include "config.h"
#include "typedefs.h"
#include "mapcomp.h"
#include "conindex.h"
#include "morsedec.h"


// --------------------------------------------------
// ----------- dynamical data structures ------------
// --------------------------------------------------

/// Combinatorial cubical multivalued map type.
#ifdef _MAP_COMP_TIGHT_
#include "mapcomp_t.h"
typedef MapComputationTight<theMapType,spcCube,spcCubes> theCubMapType;
#else
typedef MapComputation<theMapType,spcCube,spcCubes> theCubMapType;
#endif

/// The type of the index pair for the computation of the Conley index.
typedef IndexPair<theCubMapType,spcCube,spcCubes> theIndexPairType;

/// The type of the Conley index.
typedef ConleyIndex<theIndexPairType> theConleyIndexType;

/// The type of the Morse decomposition.
typedef MorseDecomposition<theCubMapType,spcCube,spcCubes>
	theMorseDecompositionType;


#endif // _CMGRAPHS_TYPEDYNS_H_

